;---------------;
; Blit8 Function ;
;---------------;
;
; Blits a single byte with the byte stored in buffer.
;
; register reference:
; -------------------
; r1 = VRAM x screen position
; r2 = VRAM y screen position
; r4 = byte to plot
; r6 = horizontal counter


blit8:
	clr
	as	2						; load the VRAM y coordinate
	bm	.blit8Exit					; Don't draw when negative
	ci	31
	bm	.blit8Exit					; Don't draw under screen
	ai	offsetY
	com							; invert it
.blit8Row:
	outs	5						; load into port 5 (row) latch

	; load the width into the horizontal counter
	lis	8
	lr	6, A

	lr	A, 1						; load the VRAM x coordinate
	ai	offsetX
	com							; invert it
.blit8Column:
	outs	4						; load into port 4 (column)

.blit8DrawBit:
	; shift graphics byte
	lr	A, 4						; load r3 (graphics byte)
	as	4						; Double, "shift left" one, with carry
	lr	4, A						; save it

	; Set color
	li	$C0
	bnc	.blit8SavePixel				; No carry means background color (OFF)
	clr							; There was carry, color ON
.blit8SavePixel:
	outs	1						; output A in p1 (color)

.blit8TransferData:
	; transfer the pixel data
	lis	6
	sl	4						; %01100000  $60
	outs	0
	sl	1						; %11000000  $C0
	outs	0

	lis	2						; Graphics update delay
blit8.savePixelDelay:
	ai	$ff
	bnz	blit8.savePixelDelay


.blit8CheckColumn:
	ds	6						; decrease r6 (horizontal counter)
	bz	.blit8Exit					; if it's 0 it's done

	ins	4						; get p4 (column)
	ai	$ff						; add 1 (complemented)
	br	.blit8Column				; branch


.blit8Exit:
	; return from the subroutine

	pop
